@@ -16,19 +16,25 @@
 # Headers in this file shall remain intact.
 
 import os
+import gettext, locale
 
 def get():
     return {
         'isinstalled':   True,
-        'gladedir':      os.path.join('/usr/local/share', 'istanbul', 'glade'),
-        'imagedir':      os.path.join('/usr/local/share', 'istanbul', 'image'),
+        'gladedir':      os.path.join('${prefix}/share', 'istanbul', 'glade'),
+        'imagedir':      os.path.join('${prefix}/share', 'istanbul', 'image'),
         'pythondir':     os.path.join('/usr/local/lib', 'istanbul', 'python'),
-        'localedir':     os.path.join('/usr/local/share', 'locale'),
+        'localedir':     os.path.join('${prefix}/share', 'locale'),
         'domain':       'istanbul',
-        'version':       '0.2.1'
+        'version':       '0.2.2'
     }
 
 config_dict = get()
 for key, value in config_dict.items():
     dictionary = locals()
     dictionary[key] = value
+
+gettext.bindtextdomain(domain, localedir)
+gettext.textdomain(domain)
+locale.bindtextdomain(domain, localedir)
+locale.textdomain(domain)
