@@ -23,17 +23,23 @@ else:
 
 import optparse
 import sys
-import locale, gettext
+import os
+import gettext
 import tempfile
+import signal
 
 from istanbul.configure import config
 from istanbul.main.save_window import SaveWindow
-from istanbul.main.select import GtkAreaSelector
+from istanbul.main.area_select import GtkAreaSelector
+from istanbul.main.window_select import WindowSelector
 from istanbul.main.preferences import Preferences
 from istanbul.main.gconf_client import GConfClient
 from istanbul.main.tray_icon import TrayIcon
 from istanbul.main.constants import RecordingState
+from istanbul.main.screencast import CmdlineScreencast
 
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
@@ -48,12 +54,27 @@ import egg.trayicon
 _ = gettext.gettext
 
 class Istanbul:
-    def __init__(self):
+    def __init__(self, options):
 
         self.encode_later = False
         self.selector = None
 
-        TrayIcon()
+        self.options = options
+        if self.options.record_file:
+            self.current_screencast = CmdlineScreencast(self.stop_callback, options)
+            self.current_screencast.start_recording(options)
+            signal.signal(signal.SIGINT, self.signal_handler)
+            signal.signal(signal.SIGTERM, self.signal_handler)
+            print 'istanbul pid:', os.getpid()
+        else:
+            TrayIcon()
+
+    def stop_callback(self, options):
+        print 'stop callback'
+
+    def signal_handler(self, signum, frame):
+        print 'signal handler'
+        self.current_screencast.stop_recording()
 
 def error_dialog(message):
     dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR,
@@ -65,24 +86,22 @@ def error_dialog(message):
 import command_line
 def main(args):
 
-    if command_line.CommandLine().Options.version:
+    options = command_line.CommandLine().Options
+
+    if options.version:
         print config.version
         return 0
 
     # check plugins installed
     reg = gst.registry_get_default()
     if not reg.find_plugin("istximagesrc"):
-        error_dialog(_("You do not have the ximagesrc GStreamer plugin installed    ."))
+        error_dialog(_("You do not have the ximagesrc GStreamer plugin installed."))
     if not reg.find_plugin("theora"):
         error_dialog(_("You do not have the theora GStreamer plugin installed."))
     if not reg.find_plugin("ogg"):
         error_dialog(_("You do not have the ogg GStreamer plugin installed."))
-        
-    locale.setlocale(locale.LC_ALL,"")
-    gettext.bindtextdomain(config.domain, config.localedir)
-    gettext.textdomain(config.domain)
-    
-    deskrec = Istanbul()
+
+    deskrec = Istanbul(options)
     gtk.main()
 
 if __name__ == "__main__":
